@@ -13,6 +13,9 @@ __all__ = [
     'LDAP_API',
     'LDAP_PASSWORD',
     'LDAP_USERNAME',
+    'AIGUILLIER_API',
+    'AIGUILLIER_PASSWORD',
+    'AIGUILLIER_USERNAME',
     'LOGS',
     'get_token'
     ]
@@ -28,6 +31,10 @@ LDAP_PASSWORD = CONFIG['LDAP_CREDENTIALS']['ldap_password']
 LOG_LEVEL = CONFIG['LOGS']['level']
 LOG_FILE = CONFIG['LOGS']['filename']
 
+AIGUILLIER_API = CONFIG['AIGUILLIER_CREDENTIALS']['aiguillier_api']
+AIGUILLIER_USERNAME = CONFIG['AIGUILLIER_CREDENTIALS']['aiguillier_user']
+AIGUILLIER_PASSWORD = CONFIG['AIGUILLIER_CREDENTIALS']['aiguillier_password']
+
 LOGS = Logger('shadok-mattermost', level=LOG_LEVEL)
 LOGS.set_file_handler(LOG_FILE)
 
